==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/structures/parsers/abstractstructureparser.cpp <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2010, 2011, 2012 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include "abstractstructureparser.h"

#include "../structuredefinitionfile.h"
#include "../script/scriptlogger.h"
#include "../structlogging.h"

#include <QFile>

AbstractStructureParser::AbstractStructureParser(const QString& pluginName, const QString& absolutePath)
    : mPluginName(pluginName)
    , mAbsolutePath(absolutePath)
{
    if (!QFile::exists(absolutePath)) {
        qCWarning(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES) << "File" << absolutePath << "does not exist, parsing structure will fail!";
    }
}

AbstractStructureParser::~AbstractStructureParser() = default;

==> okteta_0.26.2.orig.tar.xz: okteta-0.26.2/kasten/controllers/view/structures/parsers/abstractstructureparser.cpp <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2010, 2011, 2012 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include "abstractstructureparser.hpp"

#include "../structuredefinitionfile.hpp"
#include "../script/scriptlogger.hpp"
#include "../structlogging.hpp"

#include <QFile>

AbstractStructureParser::AbstractStructureParser(const QString& pluginName, const QString& absolutePath)
    : mPluginName(pluginName)
    , mAbsolutePath(absolutePath)
{
    if (!QFile::exists(absolutePath)) {
        qCWarning(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES) << "File" << absolutePath << "does not exist, parsing structure will fail!";
    }
}

AbstractStructureParser::~AbstractStructureParser() = default;
